==> haskell-logict-0.6.0.2-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-logict.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: logict
version: 0.6.0.2
id: logict-0.6.0.2-IvIE0u44i1X7ob5HesINuT
key: logict-0.6.0.2-IvIE0u44i1X7ob5HesINuT
license: BSD3
copyright: Copyright (c) 2007-2014, Dan Doel,
           Copyright (c) 2011-2013, Edward Kmett,
           Copyright (c) 2014, Roman Cheplyaka
maintainer: dan.doel@gmail.com
homepage: http://code.haskell.org/~dolio/
synopsis: A backtracking logic-programming monad.
description:
    A continuation-based, backtracking, logic programming monad.
    An adaptation of the two-continuation implementation found
    in the paper "Backtracking, Interleaving, and Terminating
    Monad Transformers" available here:
    <http://okmij.org/ftp/papers/LogicT.pdf>
category: Control
author: Dan Doel
exposed: True
exposed-modules:
    Control.Monad.Logic Control.Monad.Logic.Class
abi: 826e4c2601df8fae6c0c0a0be867760d
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/logict-0.6.0.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/logict-0.6.0.2
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/logict-0.6.0.2
hs-libraries: HSlogict-0.6.0.2-IvIE0u44i1X7ob5HesINuT
depends:
    base-4.9.1.0 mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
haddock-interfaces: /usr/share/doc/haskell-logict/html/logict.haddock
haddock-html: /usr/share/doc/haskell-logict/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-logict-0.6.0.2-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-logict.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: logict
version: 0.6.0.2
id: logict-0.6.0.2-qRJFl8TilRHIz5l3Ixb4K
key: logict-0.6.0.2-qRJFl8TilRHIz5l3Ixb4K
license: BSD3
copyright: Copyright (c) 2007-2014, Dan Doel,
           Copyright (c) 2011-2013, Edward Kmett,
           Copyright (c) 2014, Roman Cheplyaka
maintainer: dan.doel@gmail.com
homepage: http://code.haskell.org/~dolio/
synopsis: A backtracking logic-programming monad.
description:
    A continuation-based, backtracking, logic programming monad.
    An adaptation of the two-continuation implementation found
    in the paper "Backtracking, Interleaving, and Terminating
    Monad Transformers" available here:
    <http://okmij.org/ftp/papers/LogicT.pdf>
category: Control
author: Dan Doel
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Logic Control.Monad.Logic.Class
abi: 7c419a67dc5c65cc1fc4420ecc814854
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/logict-0.6.0.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/logict-0.6.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/logict-0.6.0.2
hs-libraries: HSlogict-0.6.0.2-qRJFl8TilRHIz5l3Ixb4K
depends:
    base-4.10.0.0 mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
haddock-interfaces: /usr/share/doc/haskell-logict/html/logict.haddock
haddock-html: /usr/share/doc/haskell-logict/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
